local sfx = Resources.load_audio("sfx.ogg")
local shockblast_texture = Resources.load_texture("Shockblast.png")
local bolt_texture = Resources.load_texture("Bolt.png")

function card_init(player, props)
	local action = Action.new(player, "CHARACTER_HIT")
	action:override_animation_frames({ { 1, 30 }, { 1, 30 }, { 2, 12 } })
	action:set_lockout(ActionLockout.new_animation())
	local facing = player:facing()
	local direction_list = {
		Direction.Up,
		Direction.join(facing, Direction.Up),
		facing,
		Direction.join(facing, Direction.Down),
		Direction.Down
	}
	action.on_execute_func = function(self, user)
		local field = user:field()
		self:add_anim_action(1, function()
			Resources.play_audio(sfx)
			local tile = user:current_tile()
			local attack = create_spell(player, tile, props)
			field:spawn(attack, tile)
		end)
		self:add_anim_action(2, function()
			Resources.play_audio(sfx)
			for i = 1, #direction_list, 1 do
				local tile = user:get_tile(direction_list[i], 1)
				local spell = create_spell(user, tile, props)
				field:spawn(spell, tile)
			end
		end)
	end
	return action
end

function create_spell(player, tile, props)
	local spell = Spell.new(Team.Other)
	spell:set_facing(player:facing())
	local animation = spell:animation()
	spell.timer = 42
	local flags = props.hit_flags
	local damage = props.damage
	if tile == player:current_tile() then
		spell:set_texture(shockblast_texture)
		animation:load("Shockblast.animation")
		spell.timer = 72
		flags = flags & ~Hit.Impact
		damage = math.floor(damage / 2)
	else
		spell:set_team(player:team())
		spell:set_texture(bolt_texture)
		animation:load("Bolt.animation")
	end
	local sprite = spell:sprite()
	sprite:set_layer(-3)
	animation:set_state("DEFAULT")
	animation:apply(sprite)
	animation:set_playback(Playback.Loop)
	spell:set_hit_props(
		HitProps.new(
			damage,
			flags,
			props.element,
			player:context(),
			Drag.None
		)
	)
	spell.on_update_func = function(self)
		if self.timer <= 0 then
			self:erase()
			return
		end
		self:current_tile():attack_entities(self)
		self.timer = self.timer - 1
	end
	return spell
end
